==> xmonad-extras-0.17.2-101-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-7RhmXgvpo7sJGo5rR58KTW
key:                  xmonad-extras-0.17.2-7RhmXgvpo7sJGo5rR58KTW
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  7c465d8fa9836a73790514c33403ce7f
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-7RhmXgvpo7sJGo5rR58KTW
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.2-CDVv29m1Vw4LUE2tD0bBx5
    hint-0.9.0.8-z3SY9RBdhgAPJOWz0jhNr
    libmpd-0.10.0.1-74OqL9YZOEA4J3Ri7Wnx3h mtl-2.2.2
    network-3.1.4.0-L93bqt4J89t6uDPHvRPUpA
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-EDqkzFoGY6wKc73Ouy5CMT
    xmonad-contrib-0.18.1-c7KfwiXjDILgMJJNcoPv4

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-extras-0.17.2-102-x86_64.pkg.tar.zst: usr/share/haskell/register/xmonad-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xmonad-extras
version:              0.17.2
visibility:           public
id:                   xmonad-extras-0.17.2-HdWwI2mcYQg7NY3cuV9aQr
key:                  xmonad-extras-0.17.2-HdWwI2mcYQg7NY3cuV9aQr
license:              BSD-3-Clause
maintainer:
    Sibi Prabakaran<sibi@psibi.in>, daniel@wagner-home.com, daniel.schoepe@googlemail.com

author:               The Daniels Schoepe and Wagner
homepage:             https://github.com/xmonad/xmonad-extras
synopsis:             Third party extensions for xmonad with wacky dependencies
description:
    Various modules for xmonad that cannot be added to xmonad-contrib
    because of additional dependencies.

category:             System
abi:                  4f4a240d1d25d661055881104b259a4b
exposed:              True
exposed-modules:
    XMonad.Actions.Eval XMonad.Actions.Invert XMonad.Actions.Volume
    XMonad.Hooks.PerWindowKbdLayout XMonad.Prompt.Eval
    XMonad.Prompt.MPD XMonad.Util.Brightness
    XMonad.Util.WindowPropertiesRE

import-dirs:          /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/xmonad-extras-0.17.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/xmonad-extras
hs-libraries:         HSxmonad-extras-0.17.2-HdWwI2mcYQg7NY3cuV9aQr
depends:
    X11-1.10.3-HY7umS8ccX59RQt2R5Ezi2
    alsa-mixer-0.3.0.1-64d7bL5FCNwLOsX9HNe40u base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    dbus-1.3.2-9z03nXzpOACJBUpOOdCzpB
    hint-0.9.0.8-z3SY9RBdhgAPJOWz0jhNr
    libmpd-0.10.0.1-74OqL9YZOEA4J3Ri7Wnx3h mtl-2.2.2
    network-3.1.4.0-L93bqt4J89t6uDPHvRPUpA
    regex-posix-0.96.0.2-AHNuIP1Pa8gKU2TxlSaYg9
    xmonad-0.18.0-BrfhFQhix207cl4XU3AUWF
    xmonad-contrib-0.18.1-GbDKeZ4J8Rs3WfI3sP1zZK

haddock-interfaces:   /usr/share/doc/xmonad-extras/html/xmonad-extras.haddock
haddock-html:         /usr/share/doc/xmonad-extras/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
